@@ -1,8 +1,10 @@
 from rest_framework.viewsets import ModelViewSet
 
-from .serializers import ASNSerializer, BGPSessionSerializer, RoutingPolicySerializer
-from netbox_bgp.models import ASN, BGPSession, RoutingPolicy
-from netbox_bgp.filters import ASNFilterSet, BGPSessionFilterSet, RoutingPolicyFilterSet
+from .serializers import ASNSerializer, BGPSessionSerializer, RoutingPolicySerializer, BGPPeerGroupSerializer
+from netbox_bgp.models import ASN, BGPSession, RoutingPolicy, BGPPeerGroup
+from netbox_bgp.filters import (
+    ASNFilterSet, BGPSessionFilterSet, RoutingPolicyFilterSet, BGPPeerGroupFilterSet
+)
 
 
 class ASNViewSet(ModelViewSet):
@@ -21,3 +23,9 @@ class RoutingPolicyViewSet(ModelViewSet):
     queryset = RoutingPolicy.objects.all()
     serializer_class = RoutingPolicySerializer
     filterset_class = RoutingPolicyFilterSet
+
+
+class BGPPeerGroupViewSet(ModelViewSet):
+    queryset = BGPPeerGroup.objects.all()
+    serializer_class = BGPPeerGroupSerializer
+    filterset_class = BGPPeerGroupFilterSet
